@@ -1,6 +1,7 @@
 /*****************************************************************************
 
-  Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+  Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+  All Rights Reserved.
   
   This software is subject to the provisions of the Zope Public License,
   Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,7 +12,7 @@
   
  ****************************************************************************/
 
-#define BTREETEMPLATE_C "$Id: BTreeTemplate.c,v 1.20 2001/11/28 15:50:54 matt Exp $\n"
+#define BTREETEMPLATE_C "$Id: BTreeTemplate.c,v 1.20.18.2 2002/03/08 19:12:58 jeremy Exp $\n"
 
 /*
 ** _BTree_get
@@ -1241,7 +1242,7 @@ BTree_dealloc(BTree *self)
   PER_DEL(self);
 
   Py_DECREF(self->ob_type);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 static int
