@@ -1,6 +1,7 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# All Rights Reserved.
 # 
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -206,7 +207,7 @@ class IMerge(Interface.Base):
         """
 
     def intersection(c1, c2):
-        """Compute the Union of c1 and c2.
+        """Compute the intersection of c1 and c2.
 
         If c1 is None, then c2 is returned, otherwise, if c2 is None,
         then c1 is returned.
@@ -232,11 +233,11 @@ class IIMerge(IMerge):
         if c1 is None and c2 is not None, the output is weight2 and
         c2.
 
-        if c1 is not None and c2 not None, the output is weight1 and
-        c1.
+        if c1 is not None and c2 not None and both sets, the output is 
+        weight1 and c1.
 
-        If c1 and c2 are not None, the output is 1 and a Bucket
-        such that the output values are::
+        If c1 and c2 are not None and not both sets, the output is 1 
+        and a Bucket such that the output values are::
 
           v1*weight1 + v2*weight2
 
@@ -248,8 +249,8 @@ class IIMerge(IMerge):
             v2 is 0 if the key was not in c2. Otherwise, v2 is 2, if
             c2 is a set, or the value from c2.
 
-        Note that c1 and c2 must be collections. None may not be
-        passed as one of the collections.
+        Note that c1 and c2 must be collections. 
+
         """
 
     def weightedIntersection(c1, c2, weight1=1, weight2=1):
@@ -263,7 +264,7 @@ class IIMerge(IMerge):
         if c1 is not None and c2 not None, the output is weight1 and
         c1.
 
-        If c1 and c2 are sets, the output is the sum of the weights
+        If c1 and c2 are both sets, the output is the sum of the weights
         and the (unweighted) intersection of the sets.
 
         If c1 and c2 are not None and not both sets, the output is 1
@@ -279,8 +280,7 @@ class IIMerge(IMerge):
             v2 is 0 if the key was not in c2. Otherwise, v2 is 2, if
             c2 is a set, or the value from c2.
 
-        Note that c1 and c2 must be collections. None may not be
-        passed as one of the collections.
+        Note that c1 and c2 must be collections. 
         """
 
 ###############################################################
