@@ -15,7 +15,7 @@
 
 """
 
-__version__ = '$Revision: 1.25 $'[11:-2]
+__version__ = '$Revision: 1.25.4.2 $'[11:-2]
 
 
 import  re
@@ -160,7 +160,7 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         """Reinitialize the text index."""
         self._index   = IOBTree()
         self._unindex = IOBTree()
-        if self.getLexicon():
+        if self.getLexicon() and self.vocabulary_id=='__userdefined__':
             self.getLexicon().clear()
         self._lexicon = None
 
@@ -282,9 +282,11 @@ class TextIndex(PluggableIndex.PluggableIndex, Persistent,
         try:
             source = getattr(obj, self.id)
             if callable(source):
-                source = str(source())
-            else:
+                source = source()
+
+            if not isinstance(source, UnicodeType):
                 source = str(source)
+
         except (AttributeError, TypeError):
             return 0
 
