@@ -1,90 +1,17 @@
 ##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
 # 
-# Zope Public License (ZPL) Version 1.0
-# -------------------------------------
-# 
-# Copyright (c) Digital Creations.  All rights reserved.
-# 
-# This license has been certified as Open Source(tm).
-# 
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are
-# met:
-# 
-# 1. Redistributions in source code must retain the above copyright
-#    notice, this list of conditions, and the following disclaimer.
-# 
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions, and the following disclaimer in
-#    the documentation and/or other materials provided with the
-#    distribution.
-# 
-# 3. Digital Creations requests that attribution be given to Zope
-#    in any manner possible. Zope includes a "Powered by Zope"
-#    button that is installed by default. While it is not a license
-#    violation to remove this button, it is requested that the
-#    attribution remain. A significant investment has been put
-#    into Zope, and this effort will continue if the Zope community
-#    continues to grow. This is one way to assure that growth.
-# 
-# 4. All advertising materials and documentation mentioning
-#    features derived from or use of this software must display
-#    the following acknowledgement:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    In the event that the product being advertised includes an
-#    intact Zope distribution (with copyright and license included)
-#    then this clause is waived.
-# 
-# 5. Names associated with Zope or Digital Creations must not be used to
-#    endorse or promote products derived from this software without
-#    prior written permission from Digital Creations.
-# 
-# 6. Modified redistributions of any form whatsoever must retain
-#    the following acknowledgment:
-# 
-#      "This product includes software developed by Digital Creations
-#      for use in the Z Object Publishing Environment
-#      (http://www.zope.org/)."
-# 
-#    Intact (re-)distributions of any official Zope release do not
-#    require an external acknowledgement.
-# 
-# 7. Modifications are encouraged but must be packaged separately as
-#    patches to official Zope releases.  Distributions that do not
-#    clearly separate the patches from the original work must be clearly
-#    labeled as unofficial distributions.  Modifications which do not
-#    carry the name Zope may be packaged in any form, as long as they
-#    conform to all of the clauses above.
-# 
-# 
-# Disclaimer
-# 
-#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
-#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#   SUCH DAMAGE.
-# 
-# 
-# This software consists of contributions made by Digital Creations and
-# many individuals on behalf of Digital Creations.  Specific
-# attributions are listed in the accompanying credits file.
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
-__version__='$Revision: 1.39.4.2 $'[11:-2]
+__version__='$Revision: 1.46 $'[11:-2]
 
-from string import join, split, find, rfind, lower, upper
 from urllib import quote
 
 UNSPECIFIED_ROLES=''
@@ -162,9 +89,7 @@ class BaseRequest:
 
     set=__setitem__
 
-    def __getitem__(self,key,
-                    default=_marker, # Any special internal marker will do
-                    ):
+    def get(self, key, default=None):
         """Get a variable value
 
         Return a value for the required variable name.
@@ -193,9 +118,22 @@ class BaseRequest:
             self.other[key]=v
             return v
         
-        raise KeyError, key
+        return default
 
-    __getattr__=get=__getitem__
+    def __getitem__(self, key, default=_marker):
+        v = self.get(key, default)
+        if v is _marker:
+            raise KeyError, key
+        return v
+
+    def __getattr__(self, key, default=_marker):
+        v = self.get(key, default)
+        if v is _marker:
+            raise AttributeError, key
+        return v
+
+    def set_lazy(self, key, callable):
+        pass            # MAYBE, we could do more, but let HTTPRequest do it
 
     def has_key(self,key):
         return self.get(key, _marker) is not _marker
@@ -223,7 +161,7 @@ class BaseRequest:
     def __str__(self):
         L1 = self.items()
         L1.sort()
-        return join(map(lambda item: "%s:\t%s" % item, L1), "\n")
+        return '\n'.join(map(lambda item: "%s:\t%s" % item, L1))
 
     __repr__=__str__
 
@@ -243,7 +181,7 @@ class BaseRequest:
         if path[:1]=='/':  path=path[1:]
         if path[-1:]=='/': path=path[:-1]
         clean=[]
-        for item in split(path, '/'):
+        for item in path.split('/'):
             # Make sure that certain things that dont make sense
             # cannot be traversed.
             if item in ('REQUEST', 'aq_self', 'aq_base'):
@@ -256,7 +194,7 @@ class BaseRequest:
         path=clean
     
         # How did this request come in? (HTTP GET, PUT, POST, etc.)
-        method=req_method=upper(request_get('REQUEST_METHOD', 'GET'))
+        method=req_method=request_get('REQUEST_METHOD', 'GET').upper()
         
         no_acquire_flag=0
 
@@ -322,7 +260,7 @@ class BaseRequest:
                         hasattr(object.__call__,'__roles__')):
                         roles=object.__call__.__roles__
                     if request._hacked_path:
-                        i=rfind(URL,'/')
+                        i=URL.rfind('/')
                         if i > 0: response.setBase(URL[:i])
                     break
                 if not entry_name: continue
@@ -468,7 +406,7 @@ class BaseRequest:
         if user is not None:
             if validated_hook is not None: validated_hook(self, user)
             request['AUTHENTICATED_USER']=user
-            request['AUTHENTICATION_PATH']=join(steps[:-i],'/')
+            request['AUTHENTICATION_PATH']='/'.join(steps[:-i])
 
         # Remove http request method from the URL.
         request['URL']=URL
