@@ -12,10 +12,10 @@
 ##############################################################################
 '''CGI Response Output formatter
 
-$Id: HTTPResponse.py,v 1.53 2002/01/02 15:56:04 andreasjung Exp $'''
-__version__='$Revision: 1.53 $'[11:-2]
+$Id: HTTPResponse.py,v 1.53.8.2 2002/04/15 20:55:27 Brian Exp $'''
+__version__='$Revision: 1.53.8.2 $'[11:-2]
 
-import  types, sys,  re
+import types, os, sys, re
 from string import translate, maketrans
 from types import StringType, InstanceType, LongType
 from BaseResponse import BaseResponse
@@ -92,6 +92,17 @@ start_of_header_search=re.compile('(<head[^>]*>)', re.IGNORECASE).search
 
 accumulate_header={'set-cookie': 1}.has_key
 
+tb_style = os.environ.get('HTTP_TRACEBACK_STYLE', '').lower()
+if tb_style == 'none':
+    tb_delims = None, None
+elif tb_style == 'js':
+    tb_delims = ('''<pre onclick="this.firstChild.data=this.lastChild.data">
+        &sect;<!--''',  '--></pre>')
+elif tb_style == 'plain':
+    tb_delims = '<pre>', '</pre>'
+else:
+    tb_delims = '<!--', '-->'
+
 class HTTPResponse(BaseResponse):
     """\
     An object representation of an HTTP response.
@@ -149,6 +160,17 @@ class HTTPResponse(BaseResponse):
         # think that that's all that is ever passed.
         
         return self.__class__(stdout=self.stdout, stderr=self.stderr)
+
+    _shutdown_flag = None
+    def _requestShutdown(self, exitCode=0):
+        """Request that the server shut down with exitCode after fulfilling
+           the current request."""
+        sys.ZServerExitCode = exitCode
+        self._shutdown_flag = 1
+
+    def _shutdownRequested(self):
+        """Returns true if this request requested a server shutdown."""
+        return self._shutdown_flag is not None
     
     def setStatus(self, status, reason=None):
         '''\
@@ -399,9 +421,9 @@ class HTTPResponse(BaseResponse):
         tb = '\n'.join(tb)
         tb = self.quoteHTML(tb)
         if self.debug_mode: _tbopen, _tbclose = '<PRE>', '</PRE>'
-        else:               _tbopen, _tbclose = '''<pre
-          onclick="this.firstChild.data=this.lastChild.data">
-        &sect;<!--''',  '--></pre>'
+        else:               _tbopen, _tbclose = tb_delims
+        if _tbopen is None:
+            return ''
         return "\n%s\n%s\n%s" % (_tbopen, tb, _tbclose)
 
     def redirect(self, location, status=302, lock=0):
